mix_hc

Function mix_hc 

pub fn mix_hc(hc_mult: usize) -> usize
mix_hc — the row count of hc_fn and hc_base: (2 + hc_mult) * hc_mult.

pre and post contribute one row per stream each, comb contributes hc_mult rows per stream. Sizing either tensor with a different formula still yields a well-formed 2-D weight.