pub fn use_gemv_sw(lever: bool, sw_handle: KernelHandle) -> boolExpand description
SW kernel when the model lever is on and the handle resolved.
pub fn use_gemv_sw(lever: bool, sw_handle: KernelHandle) -> boolSW kernel when the model lever is on and the handle resolved.